==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/InformacjaDodatkowaWpis.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.enums.StatusInformacjiDodatkowej;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class InformacjaDodatkowaWpis extends GenericDPSObject {
    /**
     * INFORMACJA_DODATKOWA_WPIS.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * INFORMACJA_DODATKOWA_WPIS.INFORMACJA_DODATKOWA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long informacjaDodatkowaId;

    /**
     * INFORMACJA_DODATKOWA_WPIS.PRACOWNIK_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long pracownikId;

    /**
     * INFORMACJA_DODATKOWA_WPIS.DATA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date data;

    /**
     * INFORMACJA_DODATKOWA_WPIS.STATUS
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private StatusInformacjiDodatkowej status;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return INFORMACJA_DODATKOWA_WPIS.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * INFORMACJA_DODATKOWA_WPIS.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return INFORMACJA_DODATKOWA_WPIS.INFORMACJA_DODATKOWA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getInformacjaDodatkowaId() {
        return informacjaDodatkowaId;
    }

    /**
     * INFORMACJA_DODATKOWA_WPIS.INFORMACJA_DODATKOWA_ID
     *
     * @param informacjaDodatkowaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setInformacjaDodatkowaId(Long informacjaDodatkowaId) {
        this.informacjaDodatkowaId = informacjaDodatkowaId;
    }

    /**
     * @return INFORMACJA_DODATKOWA_WPIS.PRACOWNIK_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getPracownikId() {
        return pracownikId;
    }

    /**
     * INFORMACJA_DODATKOWA_WPIS.PRACOWNIK_ID
     *
     * @param pracownikId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setPracownikId(Long pracownikId) {
        this.pracownikId = pracownikId;
    }

    /**
     * @return INFORMACJA_DODATKOWA_WPIS.DATA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getData() {
        return data;
    }

    /**
     * INFORMACJA_DODATKOWA_WPIS.DATA
     *
     * @param data
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setData(Date data) {
        this.data = data;
    }

    /**
     * @return INFORMACJA_DODATKOWA_WPIS.STATUS
     * @mbggenerated 2014-03-10 10:45:37
     */
    public StatusInformacjiDodatkowej getStatus() {
        return status;
    }

    /**
     * INFORMACJA_DODATKOWA_WPIS.STATUS
     *
     * @param status
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setStatus(StatusInformacjiDodatkowej status) {
        this.status = status;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        InformacjaDodatkowaWpis other = (InformacjaDodatkowaWpis) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getInformacjaDodatkowaId() == null ? other.getInformacjaDodatkowaId() == null : this.getInformacjaDodatkowaId().equals(other.getInformacjaDodatkowaId()))
            && (this.getPracownikId() == null ? other.getPracownikId() == null : this.getPracownikId().equals(other.getPracownikId()))
            && (this.getData() == null ? other.getData() == null : this.getData().equals(other.getData()))
            && (this.getStatus() == null ? other.getStatus() == null : this.getStatus().equals(other.getStatus()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getInformacjaDodatkowaId() == null) ? 0 : getInformacjaDodatkowaId().hashCode());
        result = prime * result + ((getPracownikId() == null) ? 0 : getPracownikId().hashCode());
        result = prime * result + ((getData() == null) ? 0 : getData().hashCode());
        result = prime * result + ((getStatus() == null) ? 0 : getStatus().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", informacjaDodatkowaId=").append(informacjaDodatkowaId);
        sb.append(", pracownikId=").append(pracownikId);
        sb.append(", data=").append(data);
        sb.append(", status=").append(status);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/InformacjaDodatkowaWpis.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.enums.StatusInformacjiDodatkowej;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class InformacjaDodatkowaWpis extends GenericDPSObject {
    /**
     * INFORMACJA_DODATKOWA_WPIS.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * INFORMACJA_DODATKOWA_WPIS.INFORMACJA_DODATKOWA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long informacjaDodatkowaId;

    /**
     * INFORMACJA_DODATKOWA_WPIS.PRACOWNIK_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long pracownikId;

    /**
     * INFORMACJA_DODATKOWA_WPIS.DATA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date data;

    /**
     * INFORMACJA_DODATKOWA_WPIS.STATUS
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private StatusInformacjiDodatkowej status;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return INFORMACJA_DODATKOWA_WPIS.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * INFORMACJA_DODATKOWA_WPIS.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return INFORMACJA_DODATKOWA_WPIS.INFORMACJA_DODATKOWA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getInformacjaDodatkowaId() {
        return informacjaDodatkowaId;
    }

    /**
     * INFORMACJA_DODATKOWA_WPIS.INFORMACJA_DODATKOWA_ID
     *
     * @param informacjaDodatkowaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setInformacjaDodatkowaId(Long informacjaDodatkowaId) {
        this.informacjaDodatkowaId = informacjaDodatkowaId;
    }

    /**
     * @return INFORMACJA_DODATKOWA_WPIS.PRACOWNIK_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getPracownikId() {
        return pracownikId;
    }

    /**
     * INFORMACJA_DODATKOWA_WPIS.PRACOWNIK_ID
     *
     * @param pracownikId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setPracownikId(Long pracownikId) {
        this.pracownikId = pracownikId;
    }

    /**
     * @return INFORMACJA_DODATKOWA_WPIS.DATA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getData() {
        return data;
    }

    /**
     * INFORMACJA_DODATKOWA_WPIS.DATA
     *
     * @param data
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setData(Date data) {
        this.data = data;
    }

    /**
     * @return INFORMACJA_DODATKOWA_WPIS.STATUS
     * @mbggenerated 2014-03-13 16:02:38
     */
    public StatusInformacjiDodatkowej getStatus() {
        return status;
    }

    /**
     * INFORMACJA_DODATKOWA_WPIS.STATUS
     *
     * @param status
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setStatus(StatusInformacjiDodatkowej status) {
        this.status = status;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        InformacjaDodatkowaWpis other = (InformacjaDodatkowaWpis) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getInformacjaDodatkowaId() == null ? other.getInformacjaDodatkowaId() == null : this.getInformacjaDodatkowaId().equals(other.getInformacjaDodatkowaId()))
            && (this.getPracownikId() == null ? other.getPracownikId() == null : this.getPracownikId().equals(other.getPracownikId()))
            && (this.getData() == null ? other.getData() == null : this.getData().equals(other.getData()))
            && (this.getStatus() == null ? other.getStatus() == null : this.getStatus().equals(other.getStatus()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getInformacjaDodatkowaId() == null) ? 0 : getInformacjaDodatkowaId().hashCode());
        result = prime * result + ((getPracownikId() == null) ? 0 : getPracownikId().hashCode());
        result = prime * result + ((getData() == null) ? 0 : getData().hashCode());
        result = prime * result + ((getStatus() == null) ? 0 : getStatus().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", informacjaDodatkowaId=").append(informacjaDodatkowaId);
        sb.append(", pracownikId=").append(pracownikId);
        sb.append(", data=").append(data);
        sb.append(", status=").append(status);
        sb.append("]");
        return sb.toString();
    }
}
